@@ -5,8 +5,8 @@ import os
 from .commit import commit
 from ...utils.env_keys import REPORT_ERROR_KEY
 from ...utils.http_client import LaunchableClient
-from ...utils.session import clean_session_files
 from ...utils.click import KeyValueType
+from ...utils.session import clean_session_files, write_build
 from tabulate import tabulate
 from ...utils.authentication import get_org_workspace
 
@@ -142,7 +142,7 @@ def build(ctx, build_name, source, max_days, no_submodules,
             "commitHashes": commitHashes
         }
 
-        client = LaunchableClient()
+        client = LaunchableClient(dry_run=ctx.obj.dry_run)
 
         res = client.request("post", "builds", payload=payload)
         res.raise_for_status()
@@ -161,3 +161,5 @@ def build(ctx, build_name, source, max_days, no_submodules,
     rows = [[name, repo_dist, commit_hash]
             for name, repo_dist, commit_hash in uniq_submodules]
     click.echo(tabulate(rows, header, tablefmt="github"))
+
+    write_build(build_name)
