@@ -49,7 +49,7 @@ class DurationType(click.ParamType):
 
 
 class KeyValueType(click.Option):
-    error_message = "Expected key-value like --option kye=value or --option key value. but got '{}'"
+    error_message = "Expected a key-value pair formatted as --option key=value, --option key:value, or --option key value, but got '{}'"
 
     def __init__(self, *args, **kwargs):
         super(KeyValueType, self).__init__(*args, **kwargs)
@@ -65,6 +65,14 @@ class KeyValueType(click.Option):
                     raise ValueError(
                         self.error_message.format(value))
 
+                value = tuple([kv[0].strip(), kv[1].strip()])
+            # case: --option key:value
+            elif ':' in value:
+                kv = value.split(':')
+                if len(kv) != 2:
+                    raise ValueError(
+                        self.error_message.format(value))
+
                 value = tuple([kv[0].strip(), kv[1].strip()])
             # case: --option key value
             else:
